==> googsystray-1.2.0.tar.gz: googsystray-1.2.0/setup.py <==
#!/usr/bin/env python

import os, sys, shutil
from distutils.core import setup
import glob
import subprocess
import commands
from distutils.command.build_py import Command

from googsystray import VERSION_STRING

try:
	import py2exe
except ImportError:
	pass
	

# This code is NOT setup to work under Windows.  
# I am OK with this.  We check the binary .mo files in
# so it's all good -- Windows can still use them
class build_i18n(Command):
	user_options = [
		('new-lang=', None, "New Language to create a .po file for"),
		('force', None, "Force rebuild"),
		]
	def initialize_options (self):
		self.new_lang = None
		self.force = False
		return
		
	def finalize_options (self):
		return
		
	def run(self):
		intl_update = commands.getoutput('which intltool-update')
		msgfmt = commands.getoutput('which msgfmt')
		msginit = commands.getoutput('which msginit')
	
		os.chdir('./googsystray/po/')
		# we generate an 'untitled.pot
		cmd = '%s --pot' % intl_update
		err, val = commands.getstatusoutput(cmd)
	
		if err:
			print val
			sys.exit("Error generating template file")
	
		# now we compare the untitled.pot to the googsystray.pot --
		diff = commands.getoutput('which diff')
		cmd = '%s googsystray.pot untitled.pot -I POT-Creation-Date' % diff
		val = commands.getoutput(cmd)
		if len(val) != 0 or self.force:
			print "Googsystray.pot updated."
			cmd = 'mv untitled.pot googsystray.pot'
			os.rename("untitled.pot", "googsystray.pot")
		else:
			os.remove("untitled.pot")
	
	
		pot_time = os.stat("googsystray.pot").st_mtime
		for i in glob.glob("*.po"):
			recomp = False
			po_time = os.stat(i).st_mtime
			try:
				mo_time = os.stat(i[:-3] + "/LC_MESSAGES/googsystray.mo").st_mtime
			except:
				mo_time = 0
			
			if pot_time > po_time:
				print "Updating " + i
				recomp = True

				cmd = '%s -g googsystray --dist %s' % (intl_update, i[:-3])
				err, val = commands.getstatusoutput(cmd)
				if err:
					print val
					sys.exit("Error generating " + i)
					
			try:	
				os.makedirs("%s/LC_MESSAGES" % i[:-3])
			except OSError, e:
				if e.errno != 17:
					print "Error making %s/LC_MESSAGES" % i[:-3]
					
			
			if po_time > mo_time or recomp:
				print "Recompiling " + i
				cmd = '%s -c %s -o %s/LC_MESSAGES/googsystray.mo' % (msgfmt, i, i[:-3])
				err, val = commands.getstatusoutput(cmd)
				if err:
					print val
					os.remove("%s/LC_MESSAGES/googsystray.mo" % i[:-3])
					sys.exit("Error generating " + i)
			
		if self.new_lang != None:
			cmd = '%s -l %s' % (msginit, self.new_lang)
			err, val = commands.getstatusoutput(cmd)
			if err:
				print val
				sys.exit("Error generating " + self.new_lang + ".po")
			
			try:	
				os.makedirs("%s/LC_MESSAGES" % self.new_lang)
			except OSError, e:
				print "Error making %s/LC_MESSAGES, can ignore if already exists" % self.new_lang
				pass
			cmd = '%s %s.po -o %s/LC_MESSAGES/googsystray.mo' % (msgfmt, self.new_lang, self.new_lang)
			err, val = commands.getstatusoutput(cmd)
			if err:
				print val
				sys.exit("Error generating " + self.new_lang)
		
		
		os.chdir('../../')


supported_translations = []

for i in os.listdir("googsystray/po"):
        if i == ".svn":
                continue
        if os.path.isdir(os.path.join("googsystray/po", i)):
                supported_translations.append(i)

if os.name == "nt":
	import _winreg
        gtkdir = "C:\\OPT\\GTK"
        pythonsp = "C:\\Python26\\Lib\\site-packages\\"
        
	files = [("icons", glob.glob("googsystray\\icons\\*.png")),
                 ("sounds", glob.glob("googsystray\\sounds\\*.wav")),
                 ("", ([os.path.join(gtkdir,'bin','libjpeg-7.dll')])),
                 ("", glob.glob(os.path.join(pythonsp, "pywin32_system32", "*.dll"))),
                 ]

	for i in supported_translations:
                files.append(("po\\"+i+"\\LC_MESSAGES\\", glob.glob("googsystray\\po\\"+i+"\\LC_MESSAGES\\*mo")))
                

elif os.name == "posix":
	# this will only be correct for freedesktop systems, which should
	# include most major distros
	# FIXME it would be much better to be generating this in some way --
	# adding a new line for each translation will blow
	files = [
		 ("share/icons", ["pkg/freedesktop/64x64/googsystray.png"]),
		 ("share/icons/hicolor/16x16/apps", ["pkg/freedesktop/16x16/googsystray.png"]),
		 ("share/icons/hicolor/32x32/apps", ["pkg/freedesktop/32x32/googsystray.png"]),
		 ("share/icons/hicolor/48x48/apps", ["pkg/freedesktop/48x48/googsystray.png"]),
		 ("share/icons/hicolor/64x64/apps", ["pkg/freedesktop/64x64/googsystray.png"]),
                 ("share/applications", ["pkg/freedesktop/googsystray.desktop"]),
                 ("share/applications", ["pkg/freedesktop/googsystray-settings.desktop"]),
                ]

	for i in supported_translations:
       		 files.append(("share/locale/"+i+"/LC_MESSAGES", ["googsystray/po/"+i+"/LC_MESSAGES/googsystray.mo"]))


setup(  cmdclass={'i18n': build_i18n},
	name = "googsystray",
	version = VERSION_STRING,
	description = "System tray notifications for Google Voice, GMail, Google Calendar, and Google Reader",
	author = "Jim Duchek",
	author_email = "jim.duchek@gmail.com",
	url = "http://www.sourceforge.net/projects/googsystray/",
	data_files = files,
	packages = ['googsystray',
		    'googsystray/gXlib',
		    'googsystray/gXlib/protocol',
		    'googsystray/gXlib/support',
		    'googsystray/gXlib/keysymdef',
		    'googsystray/gXlib/xobject',
		    ],
	package_data = { "googsystray" : ["sounds/*","icons/*"] },
	scripts = ["bin/googsystray"],
        long_description = """Really long text here.""", 
        windows=[{'script':'bin/googsystray',
        	  'icon_resources':[(1,'pkg\\win\\googsystray.ico')]}],
        options = {
                "py2exe" : {
                        "packages": "encodings",
                        "includes": "cairo,pango,pangocairo,atk,gobject,win32gui,win32api,PySnarl",
                        "dll_excludes": "kernelbase.dll,nsi.dll,dnsapi.dll,msimg32.dll",
                        "dist_dir": "dist/googsystray-" + VERSION_STRING + ".win"
                },
        },
        #zipfile = None,
	#This next part it for the Cheese Shop, look a little down the page.
	#classifiers = []	 
) 

if "py2exe" in sys.argv:
	execfile("pkg/win/post_py2exe.py", globals(), locals())
	subprocess.Popen("C:\\progra~1\\nsis\\makensis /DVERSION=" + VERSION_STRING + " pkg\\win\\script.nsi")

==> googsystray-1.3.1.tar.gz: googsystray-1.3.1/setup.py <==
#!/usr/bin/env python2

import os, sys, shutil
from distutils.core import setup
import glob
import subprocess
import commands
from distutils.command.build_py import Command

from googsystray import VERSION_STRING

try:
	import py2exe
except ImportError:
	pass
	

# This code is NOT setup to work under Windows.  
# I am OK with this.  We check the binary .mo files in
# so it's all good -- Windows can still use them
class build_i18n(Command):
	user_options = [
		('new-lang=', None, "New Language to create a .po file for"),
		('force', None, "Force rebuild"),
		]
	def initialize_options (self):
		self.new_lang = None
		self.force = False
		return
		
	def finalize_options (self):
		return
		
	def run(self):
		intl_update = commands.getoutput('which intltool-update')
		msgfmt = commands.getoutput('which msgfmt')
		msginit = commands.getoutput('which msginit')
	
		os.chdir('./googsystray/po/')
		# we generate an 'untitled.pot
		cmd = '%s --pot' % intl_update
		err, val = commands.getstatusoutput(cmd)
	
		if err:
			print (val)
			sys.exit("Error generating template file")
	
		# now we compare the untitled.pot to the googsystray.pot --
		diff = commands.getoutput('which diff')
		cmd = '%s googsystray.pot untitled.pot -I POT-Creation-Date' % diff
		val = commands.getoutput(cmd)
		if len(val) != 0 or self.force:
			print ("Googsystray.pot updated.")
			cmd = 'mv untitled.pot googsystray.pot'
			os.rename("untitled.pot", "googsystray.pot")
		else:
			os.remove("untitled.pot")
	
	
		pot_time = os.stat("googsystray.pot").st_mtime
		for i in glob.glob("*.po"):
			recomp = False
			po_time = os.stat(i).st_mtime
			try:
				mo_time = os.stat(i[:-3] + "/LC_MESSAGES/googsystray.mo").st_mtime
			except:
				mo_time = 0
			
			if pot_time > po_time:
				print ("Updating " + i)
				recomp = True

				cmd = '%s -g googsystray --dist %s' % (intl_update, i[:-3])
				err, val = commands.getstatusoutput(cmd)
				if err:
					print (val)
					sys.exit("Error generating " + i)
					
			try:	
				os.makedirs("%s/LC_MESSAGES" % i[:-3])
			except OSError, e:
				if e.errno != 17:
					print ("Error making %s/LC_MESSAGES" % i[:-3])
					
			
			if po_time > mo_time or recomp:
				print ("Recompiling " + i)
				cmd = '%s -c %s -o %s/LC_MESSAGES/googsystray.mo' % (msgfmt, i, i[:-3])
				err, val = commands.getstatusoutput(cmd)
				if err:
					print (val)
					os.remove("%s/LC_MESSAGES/googsystray.mo" % i[:-3])
					sys.exit("Error generating " + i)
			
		if self.new_lang != None:
			cmd = '%s -l %s' % (msginit, self.new_lang)
			err, val = commands.getstatusoutput(cmd)
			if err:
				print (val)
				sys.exit("Error generating " + self.new_lang + ".po")
			
			try:	
				os.makedirs("%s/LC_MESSAGES" % self.new_lang)
			except OSError, e:
				print ("Error making %s/LC_MESSAGES, can ignore if already exists" % self.new_lang)
				pass
			cmd = '%s %s.po -o %s/LC_MESSAGES/googsystray.mo' % (msgfmt, self.new_lang, self.new_lang)
			err, val = commands.getstatusoutput(cmd)
			if err:
				print (val)
				sys.exit("Error generating " + self.new_lang)
		
		
		os.chdir('../../')


supported_translations = []

for i in os.listdir("googsystray/po"):
        if i == ".svn":
                continue
        if os.path.isdir(os.path.join("googsystray/po", i)):
                supported_translations.append(i)

if os.name == "nt":
	import _winreg
        gtkdir = "C:\\OPT\\GTK"
        pythonsp = "C:\\Python27\\Lib\\site-packages\\"
        
	files = [("icons", glob.glob("googsystray\\icons\\*.png")),
                 ("sounds", glob.glob("googsystray\\sounds\\*.wav")),
                 ("", glob.glob(os.path.join(pythonsp, "pywin32_system32", "*.dll"))),
                 ]

# I think 'pixman' replaces the old jpeg support?
#                 ("", ([os.path.join(gtkdir,'bin','libjpeg-7.dll')])),


	for i in supported_translations:
                files.append(("po\\"+i+"\\LC_MESSAGES\\", glob.glob("googsystray\\po\\"+i+"\\LC_MESSAGES\\*mo")))
                

elif os.name == "posix":
	# this will only be correct for freedesktop systems, which should
	# include most major distros
	# FIXME it would be much better to be generating this in some way --
	# adding a new line for each translation will blow
	files = [
		 ("share/icons", ["pkg/freedesktop/64x64/googsystray.png"]),
		 ("share/icons/hicolor/16x16/apps", ["pkg/freedesktop/16x16/googsystray.png"]),
		 ("share/icons/hicolor/32x32/apps", ["pkg/freedesktop/32x32/googsystray.png"]),
		 ("share/icons/hicolor/48x48/apps", ["pkg/freedesktop/48x48/googsystray.png"]),
		 ("share/icons/hicolor/64x64/apps", ["pkg/freedesktop/64x64/googsystray.png"]),
                 ("share/applications", ["pkg/freedesktop/googsystray.desktop"]),
                 ("share/applications", ["pkg/freedesktop/googsystray-settings.desktop"]),
                 ("share/applications", ["pkg/freedesktop/googsystray-ical.desktop"]),
                ]

	for i in supported_translations:
       		 files.append(("share/locale/"+i+"/LC_MESSAGES", ["googsystray/po/"+i+"/LC_MESSAGES/googsystray.mo"]))


setup(  cmdclass={'i18n': build_i18n},
	name = "googsystray",
	version = VERSION_STRING,
	description = "System tray notifications for Google Voice, GMail, Google Calendar, and Google Reader",
	author = "Jim Duchek",
	author_email = "jim.duchek@gmail.com",
	url = "http://www.sourceforge.net/projects/googsystray/",
	data_files = files,
	packages = ['googsystray',
		    'googsystray/gXlib',
		    'googsystray/gXlib/protocol',
		    'googsystray/gXlib/support',
		    'googsystray/gXlib/keysymdef',
		    'googsystray/gXlib/xobject',
		    ],
	package_data = { "googsystray" : ["sounds/*","icons/*"] },
	scripts = ["bin/googsystray"],
        long_description = """Really long text here.""", 
        windows=[{'script':'bin/googsystray',
        	  'icon_resources':[(1,'pkg\\win\\googsystray.ico')]}],
        options = {
                "py2exe" : {
                	"optimize": 2,
                        "packages": "encodings",
                        "includes": "cairo,pango,pangocairo,atk,gobject,gio,win32gui,win32api,PySnarl",
                        "dll_excludes": "kernelbase.dll,nsi.dll,dnsapi.dll,msimg32.dll,powrprof.dll,usp10.dll",
                        "dist_dir": "dist/googsystray-" + VERSION_STRING + ".win"
                },
        },
        #zipfile = None,
	#This next part it for the Cheese Shop, look a little down the page.
	#classifiers = []	 
) 

if "py2exe" in sys.argv:
	execfile("pkg/win/post_py2exe.py", globals(), locals())
	subprocess.Popen("C:\\progra~1\\nsis\\makensis /DVERSION=" + VERSION_STRING + " pkg\\win\\script.nsi")
